%define rname	RubyGems
%define	oname	rubygems

# The RubyGems library has to stay out of Ruby directory three, since the
# RubyGems should be share by all Ruby implementations.
%define rubygems_dir %{_datadir}/ruby/gems

# Specify custom RubyGems root and other related macros.
%define gem_dir %{_datadir}/ruby/gems
# TODO: These folders should go into rubygem-filesystem but how to achieve it,
# since noarch package cannot provide arch dependent subpackages?
# http://rpm.org/ticket/78
%define gem_extdir %{_exec_prefix}/lib{,64}/gems

Summary:	Ruby package manager
Name:		ruby-%{rname}
Version:	1.8.24
Release:	%mkrel 9
License:	GPLv2+
Group:		Development/Ruby
URL:		http://docs.rubygems.org/
Source0:    http://rubyforge.org/frs/download.php/76073/%{oname}-%{version}.tgz
# Sources from the works by Vít Ondruch <vondruch@redhat.com>
Source100:	operating_system.rb
# https://github.com/rubygems/rubygems/issues/120
# rubygems-Patches-28631
Patch1:		rubygems-1.8.6-show-extension-build-process-in-sync.patch
# rubygems-Patches-29049
# https://github.com/rubygems/rubygems/issues/118
Patch3:		rubygems-1.8.5-show-rdoc-process-verbosely.patch
# Patches from the works by Vít Ondruch <vondruch@redhat.com>
# Fix the uninstaller, so that it doesn't say that gem doesn't exist
# when it exists outside of the GEM_HOME (already fixed in the upstream)
Patch105:	ruby-1.9.3-rubygems-1.8.11-uninstaller.patch
# Add support for installing binary extensions according to FHS.
# https://github.com/rubygems/rubygems/issues/210
Patch109:	rubygems-1.8.11-binary-extensions.patch
BuildArch:	noarch
BuildRequires:	ruby
Requires:	locales
Requires:	ruby
Requires:	rubygem(rdoc)
Provides:	%{oname} = %{version}
Provides:	ruby(rubygems) = %{version}-%{release}

%description
RubyGems is the Ruby standard for publishing and managing third party
libraries.

%prep
%setup -q -n rubygems-%{version}
%patch1 -p1 -b .insync
%patch3 -p1 -b .rdoc_v
%patch105 -p1 -b .uninst
%patch109 -p1 -b .bindir

%install
GEM_HOME=%{buildroot}/%{gem_dir} \
    ruby setup.rb --rdoc --prefix=/ \
        --destdir=%{buildroot}/%{rubygems_dir}/

mkdir -p %{buildroot}/%{_bindir}
mv %{buildroot}/%{rubygems_dir}/bin/gem %{buildroot}/%{_bindir}/gem
rm -rf %{buildroot}/%{rubygems_dir}/bin

mv %{buildroot}/%{rubygems_dir}/lib/* %{buildroot}/%{rubygems_dir}/.
# No longer needed
rmdir %{buildroot}%{rubygems_dir}/lib

# Install custom operating_system.rb.
mkdir -p %{buildroot}%{rubygems_dir}/rubygems/defaults
install -cpm 0644 %{SOURCE100} %{buildroot}%{rubygems_dir}/rubygems/defaults/

# Kill bundled cert.pem
mkdir -p %{buildroot}%{rubygems_dir}/rubygems/ssl_certs/
ln -sf %{_sysconfdir}/pki/tls/cert.pem \
	%{buildroot}%{rubygems_dir}/rubygems/ssl_certs/ca-bundle.pem

# Create gem folders.
mkdir -p %{buildroot}%{gem_dir}/{cache,gems,specifications,doc}
mkdir -p %{buildroot}%{gem_extdir}/exts

# Create macros.rubygems file for rubygems-devel
mkdir -p %{buildroot}%{_sysconfdir}/rpm/macros.d

cat >> %{buildroot}%{_sysconfdir}/rpm/macros.d/rubygems.macros << \EOF
# The RubyGems root folder.
%%gem_dir %{gem_dir}

# Common gem locations and files.
%%gem_instdir %%{gem_dir}/gems/%%{gem_name}-%%{version}
%%gem_extdir %%{_libdir}/gems/exts/%%{gem_name}-%%{version}
%%gem_libdir %%{gem_instdir}/lib
%%gem_cache %%{gem_dir}/cache/%%{gem_name}-%%{version}.gem
%%gem_spec %%{gem_dir}/specifications/%%{gem_name}-%%{version}.gemspec
%%gem_docdir %%{gem_dir}/doc/%%{gem_name}-%%{version}
EOF

%files
%doc README* 
%doc History.txt
%doc MIT.txt LICENSE.txt
%dir %{gem_dir}
%dir %{gem_dir}/cache
%dir %{gem_dir}/gems
%dir %{gem_dir}/specifications
%doc %{gem_dir}/doc
%{_bindir}/gem

%dir %{rubygems_dir}/
%{rubygems_dir}/rbconfig/
%{rubygems_dir}/rubygems/
%{rubygems_dir}/rubygems.rb
%{rubygems_dir}/ubygems.rb
%{rubygems_dir}/gauntlet_rubygems.rb

%dir %{_exec_prefix}/lib/gems
%dir %{_exec_prefix}/lib64/gems
%dir %{_exec_prefix}/lib/gems/exts
%dir %{_exec_prefix}/lib64/gems/exts

%{_sysconfdir}/rpm/macros.d/rubygems.macros


%changelog

* Fri Feb 08 2013 umeabot <umeabot> 1.8.24-9.mga3
+ Revision: 395701
- Rebuild for CVE-2013-0256

* Mon Jan 14 2013 umeabot <umeabot> 1.8.24-8.mga3
+ Revision: 380608
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 02 2012 fwang <fwang> 1.8.24-7.mga3
+ Revision: 312398
- add locales for building downstream packages

* Thu Nov 01 2012 fwang <fwang> 1.8.24-6.mga3
+ Revision: 312067
- add requires on rdoc so that we build rdoc by default for gems

* Wed Oct 31 2012 fwang <fwang> 1.8.24-5.mga3
+ Revision: 311715
- sync with fedora patches

* Thu Sep 13 2012 fwang <fwang> 1:1.8.24-4.mga3
+ Revision: 293439
+ rebuild (emptylog)

* Sun Jun 10 2012 shlomif <shlomif> 1.8.24-3.mga3
+ Revision: 259456
- New version - 1.8.24

* Mon Oct 03 2011 lebedov <lebedov> 1.7.2-3.mga2
+ Revision: 151368
- Update to 1.7.2.

* Wed Feb 16 2011 shikamaru <shikamaru> 1.5.2-1.mga1
+ Revision: 52189
- new version 1.5.2
- new version 1.5.1
- new version 1.5.0

* Mon Jan 17 2011 shikamaru <shikamaru> 1.3.7-1.mga1
+ Revision: 20990
- Spec cleaning
- reorder Tags to match the spec file syntax policy
- fix License
- fix URL (more update friendly)
- fix rpmlint warning 'mixed use of space and tabs'
- remove useless ruby require, add ruby(abi) require
- kill definition of %%buildroot
- use curly braces around custom variables (to match policy)
- use /usr/bin/env in scripts
- imported package ruby-RubyGems

